/* --------------------------------------------------------------------------------------------
 * Copyright (c) 2024 TypeFox and others.
 * Licensed under the MIT License. See LICENSE in the package root for license information.
 * ------------------------------------------------------------------------------------------ */
import * as vscode from 'vscode';
import { RegisteredFileSystemProvider, registerFileSystemOverlay, RegisteredMemoryFile } from '@codingame/monaco-vscode-files-service-override';
import React, { StrictMode } from 'react';
import ReactDOM from 'react-dom/client';
import { MonacoEditorReactComp } from '@typefox/monaco-editor-react';
import { MonacoEditorLanguageClientWrapper } from 'monaco-editor-wrapper';
import { createWrapperConfig } from './config.js';
import badPyCode from '../../../resources/python/bad.py?raw';
import { disableElement } from '../../common/client/utils.js';
export const runPythonReact = async () => {
    const badPyUri = vscode.Uri.file('/workspace/bad.py');
    const fileSystemProvider = new RegisteredFileSystemProvider(false);
    fileSystemProvider.registerFile(new RegisteredMemoryFile(badPyUri, badPyCode));
    registerFileSystemOverlay(1, fileSystemProvider);
    const onTextChanged = (textChanges) => {
        console.log(`Dirty? ${textChanges.isDirty}\ntext: ${textChanges.modified}\ntextOriginal: ${textChanges.original}`);
    };
    const wrapperConfig = createWrapperConfig('/workspace', badPyCode, '/workspace/bad.py');
    const root = ReactDOM.createRoot(document.getElementById('react-root'));
    try {
        document.querySelector('#button-start')?.addEventListener('click', async () => {
            const App = () => {
                return (React.createElement("div", { style: { 'height': '80vh', padding: '5px' } },
                    React.createElement(MonacoEditorReactComp, { wrapperConfig: wrapperConfig, style: { 'height': '100%' }, onTextChanged: onTextChanged, onLoad: (wrapper) => {
                            console.log(`Loaded ${wrapper.reportStatus().join('\n').toString()}`);
                        }, onError: (e) => {
                            console.error(e);
                        } })));
            };
            const strictMode = document.getElementById('checkbox-strictmode').checked;
            if (strictMode) {
                root.render(React.createElement(StrictMode, null,
                    React.createElement(App, null)));
            }
            else {
                root.render(React.createElement(App, null));
            }
            disableElement('checkbox-strictmode', true);
        });
        document.querySelector('#button-dispose')?.addEventListener('click', () => {
            root.render([]);
        });
    }
    catch (e) {
        console.error(e);
    }
};
//# sourceMappingURL=reactPython.js.map